@@ -1,7 +1,11 @@
+"""Extension of flask.Response.
+"""
 
 from flask import Response as ResponseBase, json, current_app, request
 
+
 class Response(ResponseBase):
+    """Extend flask.Response with support for list/dict conversion to JSON."""
     def __init__(self, content=None, *args, **kargs):
         if isinstance(content, (list, dict)):
             kargs['mimetype'] = 'application/json'
@@ -11,14 +15,17 @@ class Response(ResponseBase):
 
     @classmethod
     def force_type(cls, response, environ=None):
+        """Override with support for list/dict."""
         if isinstance(response, (list, dict)):
             return cls(response)
         else:
             return super(Response, cls).force_type(response, environ)
 
+
 def to_json(content):
+    """Converts content to json while respecting config options."""
     indent = None
-    if current_app.config['JSONIFY_PRETTYPRINT_REGULAR'] and not request.is_xhr:
+    if (current_app.config['JSONIFY_PRETTYPRINT_REGULAR']
+            and not request.is_xhr):
         indent = 2
     return json.dumps(content, indent=indent)
-
